.. _kotori-readme:

######
Kotori
######


*****
About
*****
Kotori is a multi-channel and multi-protocol data historian,
an infrastructure toolkit for data acquisition, graphing and more.

- Use it for building telemetry solutions, test benches and sensor networks.
- It offers built-in sensor adapters, flexible configuration capabilities,
  durable database storage and unattended graph visualization out of the box.
- Integrate with established hardware-, software- and data acquisition
  workflows through flexible adapter interfaces.

It is based on:

- `Twisted <https://en.wikipedia.org/wiki/Twisted_(software)>`_
- `InfluxDB <https://github.com/influxdata/influxdb>`_
- `MongoDB <https://github.com/mongodb/mongo>`_
- `Mosquitto <https://github.com/eclipse/mosquitto>`_
- `Grafana <https://github.com/grafana/grafana>`_

It supports these protocols:

- MQTT
- HTTP
- TCP
- UDP
- WebSockets
- WAMP


*******
Explore
*******
- Get a rough idea at `About Kotori <https://getkotori.org/docs/about.html>`_.
- Have a look at some `Applications <https://getkotori.org/docs/applications/>`_ where Kotori has been used.
- There are handbooks about `data acquisition <https://getkotori.org/docs/handbook/acquisition/>`_ and
  `data export <https://getkotori.org/docs/handbook/export/>`_.


*****
Setup
*****
We are offering `packages for Debian-based distributions <https://getkotori.org/docs/setup/debian-quickstart.html>`_
and `Python source packages <https://getkotori.org/docs/setup/python-package.html>`_.


***********
Source code
***********
Please find the source code of `Kotori on GitHub <https://github.com/zerotired/kotori>`_.
We are happy to receive contributions and any other feedback.

Have fun!

----

.. note:: You might want to `continue reading on our documentation space <https://getkotori.org/docs/>`_.

